@@ -5,7 +5,7 @@ use warnings;
 package Log::Any;
 
 # ABSTRACT: Bringing loggers and listeners together
-our $VERSION = '1.042';
+our $VERSION = '1.049';
 
 use Log::Any::Manager;
 use Log::Any::Proxy::Null;
@@ -45,8 +45,8 @@ sub _export_to_caller {
     my $saw_log_param;
     my @params;
     while ( my $param = shift @_ ) {
-        if ( $param eq '$log' ) {
-            $saw_log_param = 1;    # defer until later
+        if ( !$saw_log_param && $param =~ /^\$(\w+)/ ) {
+            $saw_log_param = $1;   # defer until later
             next;                  # singular
         }
         else {
@@ -60,10 +60,10 @@ sub _export_to_caller {
     }
 
     # get logger if one was requested
-    if ($saw_log_param) {
+    if ( defined $saw_log_param ) {
         no strict 'refs';
         my $proxy = $class->get_logger( category => $caller, @params );
-        my $varname = "$caller\::log";
+        my $varname = "${caller}::${saw_log_param}";
         *$varname = \$proxy;
     }
 }
@@ -133,7 +133,7 @@ Log::Any - Bringing loggers and listeners together
 
 =head1 VERSION
 
-version 1.042
+version 1.049
 
 =head1 SYNOPSIS
 
@@ -410,25 +410,6 @@ other niceties.
 
 =back
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
-
-=head1 SUPPORT
-
-=head2 Bugs / Feature Requests
-
-Please report any bugs or feature requests through the issue tracker
-at L<https://github.com/preaction/Log-Any/issues>.
-You will be notified automatically of any progress on your issue.
-
-=head2 Source Code
-
-This is open source software.  The code repository is available for
-public review and contribution under the terms of the license.
-
-L<https://github.com/preaction/Log-Any>
-
-  git clone https://github.com/preaction/Log-Any.git
-
 =head1 AUTHORS
 
 =over 4
@@ -445,11 +426,19 @@ David Golden <dagolden@cpan.org>
 
 Doug Bell <preaction@cpan.org>
 
+=item *
+
+Daniel Pittman <daniel@rimspace.net>
+
+=item *
+
+Stephen Thirlwall <sdt@cpan.org>
+
 =back
 
 =head1 CONTRIBUTORS
 
-=for stopwords bj5004 cm-perl Lucas Kanashiro Maxim Vuets Stephen Thirlwall
+=for stopwords bj5004 cm-perl Lucas Kanashiro Maros Kollar Maxim Vuets mephinet Philipp Gortan Stephen Thirlwall
 
 =over 4
 
@@ -467,17 +456,33 @@ Lucas Kanashiro <kanashiro.duarte@gmail.com>
 
 =item *
 
+Maros Kollar <maros.kollar@geizhals.at>
+
+=item *
+
 Maxim Vuets <maxim.vuets@booking.com>
 
 =item *
 
+mephinet <mephinet@gmx.net>
+
+=item *
+
+Philipp Gortan <philipp.gortan@apa.at>
+
+=item *
+
 Stephen Thirlwall <sdt@dr.com>
 
+=item *
+
+Stephen Thirlwall <stephen.thirlwall@strategicdata.com.au>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Jonathan Swartz, David Golden, and Doug Bell.
+This software is copyright (c) 2017 by Jonathan Swartz, David Golden, and Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
